#!/bin/bash
#!/bin/bash

DESIRED_VERSION=${1:-5}
if [[ ${2:-none} == 'client' ]]; then
    IS_CLIENT=true
else
    IS_CLIENT=false
fi

## Check version of binary
GLUSTERFS_VERSION=$(glusterfsd --version | head -n1 | awk '{print $2}')
[[ $GLUSTERFS_VERSION =~ ^$DESIRED_VERSION ]] || {
    echo
    echo "changed=yes comment='incorrect version $GLUSTERFS_VERSION'"
    exit 1
}

## The rest of checks are relevant only for server
$IS_CLIENT && exit 0

which gluster >/dev/null || { 
    echo
    echo "changed=yes comment='gluster command does not exist'"
    exit 1
}

for vol in $(gluster volume list); do
    ## Check volumes' status
    gluster volume info $vol | grep -q 'Status: Started' || {
        echo
        echo "changed=yes comment='volume $vol is not started'"
        exit 1;
    }
    ## Check volumes' heal info
    NUMBER_OF_BRICKS=$(gluster volume info $vol | grep -cE 'Brick[0-9]+:')
    BRICKS_CONNECTED=$(gluster volume heal $vol info | grep -c 'Status: Connected')
    [[ $NUMBER_OF_BRICKS -ne $BRICKS_CONNECTED ]] && {
        echo
        echo "changed=yes comment='some bricks of volume $vol is not connected'"
        exit 1;
    }
    BRICKS_ONLINE=$(gluster volume status $vol detail | awk -F: '/^Online/ {print $2}' | fgrep -c Y)
    [[ $NUMBER_OF_BRICKS -ne $BRICKS_ONLINE ]] && {
        echo
        echo "changed=yes comment='some bricks of volume $vol is not online'"
        exit 1;
    }

done

exit 0
