{% from "glusterfs/map.jinja" import server with context %}

{# Ensure newest package is available #}
{% set latest_pkg_version = salt['pkg.latest_version']('glusterfs-server') %}
{% set desired_version = salt['pillar.get']('_param:linux_system_repo_mcp_glusterfs_version_number') %}
{% if latest_pkg_version and salt['pkg.version_cmp'](latest_pkg_version, desired_version) >= 0 %}
    {% set ready_to_upgrade = True %}
{% else %}
    {% set ready_to_upgrade = False %}
{% endif %}


{%- if server.enabled and ready_to_upgrade %}

{# reset some options from volumes which are not supported by glusterfs 5+ #}
  {%- if server.volumes is defined %}
  {%- for name, volume in server.volumes.iteritems() %}
glusterfs_reset_lock_heal_option_{{ name }}:
  cmd.run:
    - name: gluster volume reset {{ name }} features.lock-heal
    - onlyif: "gluster volume info {{ name }} | grep -q features.lock-heal"
    - require_in:
      - service: glusterfs_stop_service

glusterfs_reset_grace_timeout_option_{{ name }}:
  cmd.run:
    - name: gluster volume reset {{ name }} features.grace-timeout
    - onlyif: "gluster volume info {{ name }} | grep -q features.grace-timeout"
    - require_in:
      - service: glusterfs_stop_service
  {%- endfor %}
  {%- endif %}

{# Update #}
glusterfs_stop_service:
  service.dead:
    - name: /usr/sbin/gluster

glusterfs_kill_processes:
  process.absent:
    - name: gluster
    - require:
      - service: glusterfs_stop_service

glusterfs_install_latest_packages:
  pkg.latest:
    - pkgs: {{ server.pkgs }}
    - refresh: true
    - require:
      - service: glusterfs_stop_service
      - process: glusterfs_kill_processes

glusterfs_service_running:
  service.running:
    - name: {{ server.service }}
    - enable: true
    - require:
      - pkg: glusterfs_install_latest_packages

{# heal volumes, just in case #}
  {%- if server.volumes is defined %}
  {%- for name, volume in server.volumes.iteritems() %}
glusterfs_volume_heal_{{ name }}:
  cmd.run:
    - name: gluster volume heal {{ name }}
    - require:
      - service: glusterfs_service_running
    - require_in:
      - cmd: glusterfs_validate_server_update
    - retry: True
  {%- endfor %}
  {%- endif %}

{# Validate #}
glusterfs_validate_server_update:
  cmd.script:
    - name: validate_glusterfs_update.sh {{ desired_version }}
    - source: salt://glusterfs/files/validate_glusterfs_update.sh
    - stateful: True
    - retry: True

{%- endif %}
